@@ -3,18 +3,22 @@ Main interface for worklink service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.worklink import (
+    from mypy_boto3_worklink import (
         Client,
         WorkLinkClient,
-        )
+    )
 
     session = boto3.Session()
 
     client: WorkLinkClient = boto3.client("worklink")
     session_client: WorkLinkClient = session.client("worklink")
+    ```
 """
-from mypy_boto3_worklink.client import WorkLinkClient, WorkLinkClient as Client
+from .client import WorkLinkClient
+
+Client = WorkLinkClient
 
 
 __all__ = ("Client", "WorkLinkClient")
